@@ -1,6 +1,8 @@
-/* -*- mode:C; tab-width:4; -*- */
+/* -*- mode:C; tab-width:8; -*- */
 /* 
- *  Author: Tomas Frydrych <tf@o-hand.com>
+ *  Author: Chris Lord		<chris@o-hand.com>
+ *  Author: Tomas Frydrych	<tf@o-hand.com>
+ *  Author: Robert Bradford	<rob@o-hand.com>
  *
  *  Copyright (c) 2005 - 2006 OpenedHand Ltd - http://o-hand.com
  *
@@ -28,10 +30,11 @@
 
 #ifdef WITH_HILDON
 #include <libosso.h>
-#include <hildon-widgets/hildon-window.h>
-#include <hildon-widgets/hildon-program.h>
-#include <hildon-widgets/hildon-time-editor.h>
-#include <hildon-widgets/hildon-date-editor.h>
+#include <hildon/hildon-window.h>
+#include <hildon/hildon-program.h>
+#include <hildon/hildon-time-editor.h>
+#include <hildon/hildon-date-editor.h>
+#include <hildon/hildon-note.h>
 #endif
 
 #define TIME_MARKUP "%k:%M\n<small>%d %b %Y</small>"
@@ -293,6 +296,8 @@ dates_date_changed_cb (DatesView *view, DatesData *d)
 {
     struct tm timem;
     gchar buffer[256];
+    gchar *buffer_utf8;
+
     const icaltimetype *date = dates_view_get_date (view);
 #ifndef WITH_HILDON
     gchar *text;
@@ -310,7 +315,10 @@ dates_date_changed_cb (DatesView *view, DatesData *d)
 #endif
 
     strftime (buffer, 255, "<big><b>%A %d %B, %Y</b></big>", &timem);
-    gtk_label_set_markup (GTK_LABEL (d->header_label), buffer);
+    buffer_utf8 = g_locale_to_utf8(buffer, -1,
+		NULL, NULL, NULL);
+    gtk_label_set_markup (GTK_LABEL (d->header_label), buffer_utf8);
+    g_free (buffer_utf8);
 }
 
 void
@@ -332,15 +340,19 @@ dates_about_cb (GtkWidget *widget, DatesData *d)
 	};
 
 	const gchar *licence =
-		"This program is free software; you can redistribute it and/or modify\n"
-		"it under the terms of the GNU General Public License as published by\n"
-		"the Free Software Foundation; either version 2, or (at your option)\n"
-		"any later version.\n"
-		"\n"
-		"This program is distributed in the hope that it will be useful,\n"
-		"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-		"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
-		"GNU General Public License for more details.";
+		_("This program is free software; you can redistribute it and/or modify\n"
+                  "it under the terms of the GNU General Public License as published by\n"
+                  "the Free Software Foundation; either version 2, or (at your option)\n"
+                  "any later version.\n"
+                  "\n"
+                  "This program is distributed in the hope that it will be useful,\n"
+                  "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+                  "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+                  "GNU General Public License for more details.");
+
+        /* Translators: please translate this as your own name and optionally email
+	   like so: "Your Name <your@email.com>" */
+        const char *translator_credits = _("translator-credits");
 #endif
 	
 	if (!pixb)
@@ -365,14 +377,14 @@ dates_about_cb (GtkWidget *widget, DatesData *d)
 			
 			"license",
 			licence,
+
+                        "translator-credits",
+                        translator_credits,
 #endif
 
 			"logo",
 			pixb,
 
-			"name",
-			PACKAGE_NAME,
-			
 			"version",
 			PACKAGE_VERSION,
 			
@@ -809,7 +821,7 @@ dates_details_time_cb (DatesData *d, ECalComponentDateTime *time)
     /* Set time */
     hildon_time_editor_set_time (time_edit, time->value->hour,
 				 time->value->minute, 0);
-    hildon_time_editor_show_seconds (time_edit, FALSE);
+    hildon_time_editor_set_show_seconds (time_edit, FALSE);
 #endif
 	
     gtk_widget_hide (d->time_forever_checkbutton);
@@ -1044,6 +1056,9 @@ dates_delete_cb (GtkWidget *source, DatesData *d)
     ECalComponentText summary;
     GtkWidget *widget;
     const char *value;
+#ifdef WITH_HILDON
+    gchar *tmp;
+#endif
 
     e_cal_component_get_summary (d->comp, &summary);
     widget = d->details_dialog;
@@ -1055,9 +1070,19 @@ dates_delete_cb (GtkWidget *source, DatesData *d)
 	value = summary.altrep;
     else {
 	g_warning ("Deleting event with no summary");
-	value = "Unknown event";
+	value = _("Unknown event");
     }
 		
+#ifdef WITH_HILDON
+    tmp = g_strdup_printf(_("Are you sure you want to delete event '%s'?"), value);
+    widget = hildon_note_new_confirmation_add_buttons(
+        GTK_WINDOW (d->main_window),
+        tmp,
+        _("Keep event"), GTK_RESPONSE_NO,
+        _("Delete event"), GTK_RESPONSE_YES,
+        NULL);
+    g_free(tmp);
+#else
     widget = gtk_message_dialog_new (
 	GTK_WINDOW (d->main_window),
 	GTK_DIALOG_MODAL,
@@ -1069,7 +1094,7 @@ dates_delete_cb (GtkWidget *source, DatesData *d)
 			    _("Keep event"), GTK_RESPONSE_NO,
 			    _("Delete event"), GTK_RESPONSE_YES,
 			    NULL);
-	
+#endif
     if (gtk_dialog_run (GTK_DIALOG (widget)) == GTK_RESPONSE_YES) {
 	/* Reset event type, in case this was a new event */
 	d->event_type = NORMAL;
@@ -1205,7 +1230,7 @@ dates_calendar_combo_changed_cb (GtkComboBox *widget, DatesData *d)
     ECalComponent *comp = d->comp;
     GtkTreeIter iter;
 	
-    gtk_combo_box_get_active_iter (widget, &iter);
+    if (!gtk_combo_box_get_active_iter (widget, &iter)) return;
     gtk_tree_model_get (gtk_combo_box_get_model (widget),
 			&iter, COL_CALPTR, &c, -1);
 	
@@ -1275,9 +1300,9 @@ dates_cal_open_cb (ECal *ecal, ECalendarStatus status, DatesData *d)
 				GTK_DIALOG_MODAL | GTK_DIALOG_NO_SEPARATOR,
 				GTK_MESSAGE_ERROR,
 				GTK_BUTTONS_CLOSE,
-				"Dates failed to open the system calendar. "
-				"You will not be able to view or create "
-				"events; this may be remedied by restarting.");
+				_("Dates failed to open the system calendar. "
+				  "You will not be able to view or create "
+				  "events; this may be remedied by restarting."));
 			gtk_dialog_run (GTK_DIALOG (dialog));
 		}
 		return;
