@@ -19,10 +19,10 @@
 #include <string.h>
 
 #include <libosso.h>
-#include <hildon-widgets/hildon-window.h>
-#include <hildon-widgets/hildon-program.h>
-#include <hildon-widgets/hildon-time-editor.h>
-#include <hildon-widgets/hildon-date-editor.h>
+#include <hildon/hildon-window.h>
+#include <hildon/hildon-program.h>
+#include <hildon/hildon-time-editor.h>
+#include <hildon/hildon-date-editor.h>
 
 #include "dates_types.h"
 #include "dates_callbacks.h"
@@ -399,7 +399,7 @@ dates_platform_init (DatesData * d)
 		g_debug ("Creating HildonProgram");
 #endif
 	g_set_application_name (_("Dates"));
-	d->program = hildon_program_new ();
+	d->program = hildon_program_get_instance ();
 
 #ifdef DEBUG
 	if (d->debug & DATES_DEBUG_HILDON)
@@ -503,6 +503,7 @@ create_main_window (DatesData * d, GtkWidget * toolbar,
 	GtkWidget *main_vbox;
 	GtkWidget *image;
 	GtkWidget *scrolled_window;
+	gchar* tmp_str;
 
 	gtk_widget_show (menu);
 	hildon_program_set_common_menu(d->program, GTK_MENU(menu));
@@ -519,7 +520,9 @@ create_main_window (DatesData * d, GtkWidget * toolbar,
 	gtk_box_pack_start (GTK_BOX (main_vbox), d->header_eventbox,
 						FALSE, FALSE, 0);
 
-	d->header_label = gtk_label_new (_("<big><b>Dates</b></big>"));
+	tmp_str = g_strdup_printf ("<big><b>%s</b></big>", _("Dates"));
+	d->header_label = gtk_label_new (tmp_str);
+	g_free (tmp_str);
 	gtk_widget_show (d->header_label);
 	gtk_container_add (GTK_CONTAINER (d->header_eventbox), d->header_label);
 	gtk_label_set_use_markup (GTK_LABEL (d->header_label), TRUE);
