@@ -100,14 +100,14 @@ dates_load_calendars (DatesData *d)
 
 		base_uri = g_strdup_printf ("file://%s", dirname);
 
-		local_group = e_source_group_new ("On This Computer", base_uri);
+		local_group = e_source_group_new (_("On This Computer"), base_uri);
 
 		g_free (path);
 		g_free (dirname);
 		g_free (base_uri);
 
 		/* Now create a default source for it */
-		system_source = e_source_new ("Personal", "system");
+		system_source = e_source_new (_("Personal"), "system");
 
 		/* Default Evolution colour */
 		e_source_set_color (system_source, 0xBECEDD);
@@ -145,7 +145,7 @@ dates_load_calendars (DatesData *d)
 	{
 		ESourceGroup *remote_group;
 		
-		remote_group = e_source_group_new ("On The Web", "webcal://");
+		remote_group = e_source_group_new (_("On The Web"), "webcal://");
 
 		if (!e_source_list_add_group (source_list, remote_group, 0))
 			g_warning ("Error adding group");
@@ -397,7 +397,9 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	context = g_option_context_new (" - A light-weight, zooming calendar");
+	g_set_application_name (_("Dates"));
+
+	context = g_option_context_new (_(" - A light-weight, zooming calendar"));
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
