@@ -23,7 +23,7 @@
 
 #ifdef WITH_HILDON
 #include <libosso.h>
-#include <hildon-widgets/hildon-program.h>
+#include <hildon/hildon-program.h>
 #endif
 
 #include "dates_view.h"
